summaryrefslogtreecommitdiffstats
path: root/python/pykde/extra/kde303/kurifilter.h
diff options
context:
space:
mode:
Diffstat (limited to 'python/pykde/extra/kde303/kurifilter.h')
-rw-r--r--python/pykde/extra/kde303/kurifilter.h66
1 files changed, 33 insertions, 33 deletions
diff --git a/python/pykde/extra/kde303/kurifilter.h b/python/pykde/extra/kde303/kurifilter.h
index b0138176..0c15d3ea 100644
--- a/python/pykde/extra/kde303/kurifilter.h
+++ b/python/pykde/extra/kde303/kurifilter.h
@@ -21,8 +21,8 @@
#ifndef __kurifilter_h__
#define __kurifilter_h__ "$Id: kurifilter.h,v 1.23 2002/03/04 04:17:37 lunakl Exp $"
-#include <qptrlist.h>
-#include <qobject.h>
+#include <tqptrlist.h>
+#include <tqobject.h>
#include <kurl.h>
@@ -42,7 +42,7 @@ class KCModule;
*
* @sect Example
* <pre>
-* QString text = "kde.org";
+* TQString text = "kde.org";
* KURIFilterData d = text;
* bool filtered = KURIFilter::self()->filter( d );
* if( filtered )
@@ -105,7 +105,7 @@ public:
*
* @param url is the string to be filtered.
*/
- KURIFilterData( const QString& url ) { init( url ); }
+ KURIFilterData( const TQString& url ) { init( url ); }
/**
* Copy constructor.
@@ -149,11 +149,11 @@ public:
* This functions returns the error message set
* by the plugin whenever the uri type is set to
* KURIFilterData::ERROR. Otherwise, it returns
- * a QString::null.
+ * a TQString::null.
*
* @return the error message or a NULL when there is none.
*/
- QString errorMsg() const { return m_strErrMsg; }
+ TQString errorMsg() const { return m_strErrMsg; }
/**
* Returns the URI type.
@@ -172,7 +172,7 @@ public:
*
* @param url the string to be filtered.
*/
- void setData( const QString& url ) { init( url ); }
+ void setData( const TQString& url ) { init( url ); }
/**
* Same as above except the argument is a URL.
@@ -201,12 +201,12 @@ public:
* @param abs_path the abolute path to the local resource.
* @return true if absolute path is successfully set. Otherwise, false.
*/
- bool setAbsolutePath( const QString& /* abs_path */ );
+ bool setAbsolutePath( const TQString& /* abs_path */ );
/**
* Returns the absolute path if one has already been set.
*/
- QString absolutePath() const;
+ TQString absolutePath() const;
/**
* Returns true if the supplied data has an absolute path.
@@ -217,9 +217,9 @@ public:
* Returns the command line options and arguments for a
* local resource when present.
*
* @return options and arguments when present, otherwise QString::null
*/
- QString argsAndOptions() const;
+ TQString argsAndOptions() const;
/**
* Returns true if the current data is a local resource with
@@ -237,7 +237,7 @@ public:
*
* @return the name of the icon associated with the resource
*/
- QString iconName();
+ TQString iconName();
/**
* Overloaded assigenment operator.
@@ -257,21 +257,21 @@ public:
*
* @return an instance of a KURIFilterData object.
*/
- KURIFilterData& operator=( const QString& url ) { init( url ); return *this; }
+ KURIFilterData& operator=( const TQString& url ) { init( url ); return *this; }
protected:
/**
* Initializes the KURIFilterData on construction.
*/
- void init( const KURL& url = QString::null );
+ void init( const KURL& url = TQString::null );
private:
bool m_bFiltered;
bool m_bChanged;
- QString m_strErrMsg;
- QString m_strIconName;
+ TQString m_strErrMsg;
+ TQString m_strIconName;
KURL m_pURI;
URITypes m_iType;
@@ -307,14 +307,14 @@ public:
* @param name the name of the plugin.
* @param pri the priority of the plugin.
*/
- KURIFilterPlugin( QObject *parent = 0, const char *name = 0, double pri = 1.0 );
+ KURIFilterPlugin( TQObject *parent = 0, const char *name = 0, double pri = 1.0 );
/**
* Returns the filter's name.
*
* @return A string naming the filter.
*/
- virtual QString name() const { return m_strName; }
+ virtual TQString name() const { return m_strName; }
/**
* Returns the filter's priority.
@@ -342,14 +342,14 @@ public:
*
* @return A configuration module, @p null if the filter isn't configurable.
*/
- virtual KCModule *configModule( QWidget*, const char* ) const { return 0; }
+ virtual KCModule *configModule( TQWidget*, const char* ) const { return 0; }
/**
* Returns the name of the configuration module for the filter.
*
* @return the name of a configuration module or @p null if none.
*/
- virtual QString configName() const { return name(); }
+ virtual TQString configName() const { return name(); }
protected:
@@ -361,7 +361,7 @@ protected:
/**
* Sets the error message in @p data to @p errormsg.
*/
- void setErrorMsg ( KURIFilterData& data, const QString& errmsg ) const {
+ void setErrorMsg ( KURIFilterData& data, const TQString& errmsg ) const {
data.m_strErrMsg = errmsg;
}
@@ -377,9 +377,9 @@ protected:
* Sets the arguments and options string in @p data
* to @p args if any were found during filterting.
*/
- void setArguments( KURIFilterData& data, const QString& args ) const;
+ void setArguments( KURIFilterData& data, const TQString& args ) const;
- QString m_strName;
+ TQString m_strName;
double m_dblPriority;
protected:
@@ -389,7 +389,7 @@ private:
};
-class KURIFilterPluginList : public QPtrList<KURIFilterPlugin>
+class KURIFilterPluginList : public TQPtrList<KURIFilterPlugin>
{
public:
virtual int compareItems(Item a, Item b)
@@ -440,7 +440,7 @@ private:
* simply invoke the corresponding function to obtain
* the filtered string or URL instead of a boolean flag:
* <pre>
- * QString u = KURIFilter::self()->filteredURI( "kde.org" );
+ * TQString u = KURIFilter::self()->filteredURI( "kde.org" );
* </pre>
*
* You can also specify only specific filter(s) to be applied
@@ -450,10 +450,10 @@ private:
* enteries in the \".desktop\" files. Here are a couple of
* examples:
* <pre>
- * QString text = "kde.org";
+ * TQString text = "kde.org";
* bool filtered = KURIFilter::self()->filterURI( text, "KShortURIFilter" );
*
- * QStringList list;
+ * TQStringList list;
* list << "KShortURIFilter" << "MyFilter";
* bool filtered = KURIFilter::self()->filterURI( text, list );
* </pre>
@@ -492,7 +492,7 @@ public:
*
* @return a boolean indicating whether the URI has been changed
*/
- bool filterURI( KURIFilterData& data, const QStringList& filters = QStringList() );
+ bool filterURI( KURIFilterData& data, const TQStringList& filters = TQStringList() );
/**
* Filters the URI given by the URL.
@@ -507,7 +507,7 @@ public:
*
* @return a boolean indicating whether the URI has been changed
*/
- bool filterURI( KURL &uri, const QStringList& filters = QStringList() );
+ bool filterURI( KURL &uri, const TQStringList& filters = TQStringList() );
/**
* Filters a string representing a URI.
@@ -522,7 +522,7 @@ public:
*
* @return a boolean indicating whether the URI has been changed
*/
- bool filterURI( QString &uri, const QStringList& filters = QStringList() );
+ bool filterURI( TQString &uri, const TQStringList& filters = TQStringList() );
/**
* Returns the filtered URI.
@@ -537,7 +537,7 @@ public:
*
* @return the filtered URI or null if it cannot be filtered
*/
- KURL filteredURI( const KURL &uri, const QStringList& filters = QStringList() );
+ KURL filteredURI( const KURL &uri, const TQStringList& filters = TQStringList() );
/**
* Return a filtered string representation of a URI.
@@ -552,7 +552,7 @@ public:
*
* @return the filtered URI or null if it cannot be filtered
*/
- QString filteredURI( const QString &uri, const QStringList& filters = QStringList() );
+ TQString filteredURI( const TQString &uri, const TQStringList& filters = TQStringList() );
/**
* Return an iterator to iterate over all loaded
@@ -560,7 +560,7 @@ public:
*
* @return a plugin iterator.
*/
- QPtrListIterator<KURIFilterPlugin> pluginsIterator() const;
+ TQPtrListIterator<KURIFilterPlugin> pluginsIterator() const;
protected:
@@ -217,9 +217,9 @@ public:
* local resource when present.
*
- * @return options and arguments when present, otherwise QString::null
+ * @return options and arguments when present, otherwise TQString::null
*/